@@ -3,12 +3,11 @@
 #include "KinoSearch/Analysis/CaseFolder.h"
 #include "KinoSearch/Analysis/Token.h"
 #include "KinoSearch/Analysis/Inversion.h"
-#include "KinoSearch/Util/ByteBuf.h"
 
 CaseFolder*
 CaseFolder_new()
 {
-    CaseFolder *self = (CaseFolder*)VTable_Make_Obj(&CASEFOLDER);
+    CaseFolder *self = (CaseFolder*)VTable_Make_Obj(CASEFOLDER);
     return CaseFolder_init(self);
 }
 
@@ -41,7 +40,7 @@ Hash*
 CaseFolder_dump(CaseFolder *self)
 {
     CaseFolder_dump_t super_dump 
-        = (CaseFolder_dump_t)SUPER_METHOD(&CASEFOLDER, CaseFolder, Dump);
+        = (CaseFolder_dump_t)SUPER_METHOD(CASEFOLDER, CaseFolder, Dump);
     return super_dump(self);
 }
 
@@ -49,7 +48,7 @@ CaseFolder*
 CaseFolder_load(CaseFolder *self, Obj *dump)
 {
     CaseFolder_load_t super_load 
-        = (CaseFolder_load_t)SUPER_METHOD(&CASEFOLDER, CaseFolder, Load);
+        = (CaseFolder_load_t)SUPER_METHOD(CASEFOLDER, CaseFolder, Load);
     CaseFolder *loaded = super_load(self, dump);
     return CaseFolder_init(loaded);
 }
