@@ -7,7 +7,7 @@
 Tokenizer*
 Tokenizer_new(const CharBuf *pattern)
 {
-    Tokenizer *self = (Tokenizer*)VTable_Make_Obj(&TOKENIZER);
+    Tokenizer *self = (Tokenizer*)VTable_Make_Obj(TOKENIZER);
     return Tokenizer_init(self, pattern);
 }
 
@@ -37,7 +37,7 @@ Obj*
 Tokenizer_dump(Tokenizer *self)
 {
     Tokenizer_dump_t super_dump
-        = (Tokenizer_dump_t)SUPER_METHOD(&TOKENIZER, Tokenizer, Dump);
+        = (Tokenizer_dump_t)SUPER_METHOD(TOKENIZER, Tokenizer, Dump);
     Hash *dump = (Hash*)ASSERT_IS_A(super_dump(self), HASH);
     Hash_Store_Str(dump, "pattern", 7, Obj_Dump(self->pattern));
     return (Obj*)dump;
@@ -48,10 +48,10 @@ Tokenizer_load(Tokenizer *self, Obj *dump)
 {
     Hash *source = (Hash*)ASSERT_IS_A(dump, HASH);
     Tokenizer_load_t super_load 
-        = (Tokenizer_load_t)SUPER_METHOD(&TOKENIZER, Tokenizer, Load);
+        = (Tokenizer_load_t)SUPER_METHOD(TOKENIZER, Tokenizer, Load);
     Tokenizer *loaded = super_load(self, dump);
-    CharBuf *pattern 
-        = (CharBuf*)ASSERT_IS_A(Hash_Fetch_Str(source, "pattern", 7), CHARBUF);
+    CharBuf *pattern = (CharBuf*)ASSERT_IS_A(
+        Hash_Fetch_Str(source, "pattern", 7), CHARBUF);
     return Tokenizer_init(loaded, pattern);
 }
 
@@ -59,7 +59,7 @@ bool_t
 Tokenizer_dump_equals(Tokenizer *self, Obj *dump)
 {
     Tokenizer_dump_equals_t super_dump_equals = (Tokenizer_dump_equals_t)
-        SUPER_METHOD(&TOKENIZER, Tokenizer, Dump_Equals);
+        SUPER_METHOD(TOKENIZER, Tokenizer, Dump_Equals);
     if (!super_dump_equals(self, dump)) {
         return false;
     }
