@@ -15,7 +15,7 @@ S_refresh_lex_q(SegLexQueue *lex_q, VArray *seg_lexicons, Obj *target);
 PolyLexicon*
 PolyLex_new(const CharBuf *field, VArray *sub_readers)
 {
-    PolyLexicon *self = (PolyLexicon*)VTable_Make_Obj(&POLYLEXICON);
+    PolyLexicon *self = (PolyLexicon*)VTable_Make_Obj(POLYLEXICON);
     return PolyLex_init(self, field, sub_readers);
 }
 
@@ -188,7 +188,7 @@ PolyLex_get_term(PolyLexicon *self)
 SegLexQueue*
 SegLexQ_new(u32_t max_size)
 {
-    SegLexQueue *self = (SegLexQueue*)VTable_Make_Obj(&SEGLEXQUEUE);
+    SegLexQueue *self = (SegLexQueue*)VTable_Make_Obj(SEGLEXQUEUE);
     return (SegLexQueue*)PriQ_init((PriorityQueue*)self, max_size);
 }
 
