@@ -7,7 +7,7 @@ __END__
 __AUTO_XS__
 
 my $synopsis = <<'END_SYNOPSIS';
-    my $bit_vec = KinoSearch::Util::BitVector->new(
+    my $bit_vec = KinoSearch::Obj::BitVector->new(
         capacity => $searcher->doc_max + 1,
     );
     my $bit_collector = KinoSearch::Search::HitCollector::BitCollector->new(
