@@ -2,16 +2,6 @@ use strict;
 use warnings;
 
 use KinoSearch;
-package KinoSearch::Util::Debug;
-use base qw( Exporter );
-
-our @EXPORT_OK = qw(
-    DEBUG
-    DEBUG_PRINT
-    DEBUG_ENABLED
-    ASSERT
-    set_env_cache
-);
 
 1;
 
@@ -39,6 +29,22 @@ CODE:
     RETVAL = KINO_DEBUG_ENABLED;
 OUTPUT: RETVAL
 
+=for comment
+
+Keep track of any KS objects that have been assigned to global Perl variables.
+This is useful when accounting how many objects should have been destroyed and
+diagnosing memory leaks.
+
+=cut
+
+void
+track_globals(...)
+PPCODE:
+{
+    CHY_UNUSED_VAR(items);
+    KINO_IFDEF_DEBUG(kino_Debug_num_globals++;);
+}
+
 void
 set_env_cache(str)
     char *str;
@@ -51,21 +57,28 @@ ASSERT(maybe)
 PPCODE:
     KINO_ASSERT(maybe, "XS ASSERT binding test");
 
-__POD__
+IV
+num_allocated()
+CODE:
+    RETVAL = kino_Debug_num_allocated;
+OUTPUT: RETVAL
 
-=begin devdocs
+IV
+num_freed()
+CODE:
+    RETVAL = kino_Debug_num_freed;
+OUTPUT: RETVAL
 
-=head1 PRIVATE CLASS
+IV
+num_globals()
+CODE:
+    RETVAL = kino_Debug_num_globals;
+OUTPUT: RETVAL
 
-KinoSearch::Util::Debug - Interface for C-level debug utils.
+__COPYRIGHT__
 
-=head1 COPYRIGHT
+Copyright 2005-2009 Marvin Humphrey
 
-Copyright 2007 Marvin Humphrey
+This program is free software; you can redistribute it and/or modify
+under the same terms as Perl itself.
 
-=head1 LICENSE, DISCLAIMER, BUGS etc.
-
-See L<KinoSearch> version 0.20.
-
-=end devdocs
-=cut
